/*

matchl.h

Copyright (C) 2011 Erwin Waterlander

This is free software; you can redistribute it and/or modify it under the
terms of the GNU General Public License, see the file COPYING.

*/

#ifndef _MATCHL_H
#define _MATCHL_H

#include "match.h"

int dd_matchl(const char *string, const char *pattern, int ignore_case, int ignore_diacritics);

#endif /* _MATCHL_H */
